@@ -487,4 +487,9 @@ sub quote_literal {
     return "'$txt'";
 }
 
+sub detect_sys_libs {
+  my $self = shift;
+  $self->pkg_config('pkg-config', '/dev/null');
+};
+
 1;
